@@ -1,4 +1,6 @@
-pub mod logreader;
+mod addresses;
+pub(crate) mod logreader;
+mod requests;
 
 use crate::logreader::{EventParseError, LogReader};
 use airnode_abi::{DecodingError, ABI};
@@ -402,6 +404,60 @@ pub struct AirnodeState {
 }
 
 impl AirnodeEvent {
+    pub fn get_error(&self) -> Option<String> {
+        match self {
+            Self::ClientFullRequestCreatedA { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::ClientRequestCreatedA { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::ClientShortRequestCreatedA { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::CreatedTemplate { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::FailedRequest { error_message, .. } => {
+                if error_message.len() > 0 {
+                    Some(error_message.clone())
+                } else {
+                    None
+                }
+            }
+            Self::MadeFullRequest { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::MadeTemplateRequest { error, .. } => error.clone().map(|x| x.to_string()),
+            Self::TemplateCreatedA { error, .. } => error.clone().map(|x| x.to_string()),
+            _ => None,
+        }
+    }
+
+    pub fn get_addresses(&self) -> Vec<H160> {
+        addresses::get_addresses(self)
+    }
+
+    pub fn get_request_id(&self) -> Option<U256> {
+        requests::get_request_id(self)
+    }
+
+    // requester_index: only for pre-alpha
+    pub fn get_requester_index(&self) -> Option<U256> {
+        requests::get_requester_index(self)
+    }
+
+    pub fn get_endpoint_id(&self) -> Option<U256> {
+        requests::get_endpoint_id(self)
+    }
+
+    // airnode: only for beta-protocol
+    pub fn get_airnode(&self) -> Option<H160> {
+        requests::get_airnode(self)
+    }
+
+    // provider_id: only for pre-alpha
+    pub fn get_provider_id(&self) -> Option<U256> {
+        requests::get_provider_id(self)
+    }
+
+    pub fn get_template_id(&self) -> Option<U256> {
+        requests::get_template_id(self)
+    }
+    pub fn get_fulfill_function_id(&self) -> Option<u64> {
+        requests::get_fulfill_function_id(self)
+    }
+
     pub fn from_log(log: &web3::types::Log) -> Result<Self, EventParseError> {
         let t0 = log.topics[0];
 
